@@ -9,6 +9,7 @@ import (
 	"strings"
 	"testing"
 
+	"github.com/bazelbuild/bazelisk/config"
 	"github.com/bazelbuild/bazelisk/core"
 	"github.com/bazelbuild/bazelisk/httputil"
 	"github.com/bazelbuild/bazelisk/repositories"
@@ -42,7 +43,7 @@ func TestResolveVersion(t *testing.T) {
 
 	gcs := &repositories.GCSRepo{}
 	repos := core.CreateRepositories(nil, gcs, nil, nil, nil, false)
-	version, _, err := repos.ResolveVersion(tmpDir, versions.BazelUpstream, "4.0.0")
+	version, _, err := repos.ResolveVersion(tmpDir, versions.BazelUpstream, "4.0.0", config.Null())
 
 	if err != nil {
 		t.Fatalf("Version resolution failed unexpectedly: %v", err)
@@ -60,7 +61,7 @@ func TestResolvePatchVersion(t *testing.T) {
 
 	gcs := &repositories.GCSRepo{}
 	repos := core.CreateRepositories(nil, gcs, nil, nil, nil, false)
-	version, _, err := repos.ResolveVersion(tmpDir, versions.BazelUpstream, "4.0.0-patch1")
+	version, _, err := repos.ResolveVersion(tmpDir, versions.BazelUpstream, "4.0.0-patch1", config.Null())
 
 	if err != nil {
 		t.Fatalf("Version resolution failed unexpectedly: %v", err)
@@ -82,7 +83,7 @@ func TestResolveLatestRcVersion(t *testing.T) {
 
 	gcs := &repositories.GCSRepo{}
 	repos := core.CreateRepositories(nil, gcs, nil, nil, nil, false)
-	version, _, err := repos.ResolveVersion(tmpDir, versions.BazelUpstream, "last_rc")
+	version, _, err := repos.ResolveVersion(tmpDir, versions.BazelUpstream, "last_rc", config.Null())
 
 	if err != nil {
 		t.Fatalf("Version resolution failed unexpectedly: %v", err)
@@ -100,7 +101,7 @@ func TestResolveLatestRcVersion_WithFullRelease(t *testing.T) {
 
 	gcs := &repositories.GCSRepo{}
 	repos := core.CreateRepositories(nil, gcs, nil, nil, nil, false)
-	version, _, err := repos.ResolveVersion(tmpDir, versions.BazelUpstream, "last_rc")
+	version, _, err := repos.ResolveVersion(tmpDir, versions.BazelUpstream, "last_rc", config.Null())
 
 	if err != nil {
 		t.Fatalf("Version resolution failed unexpectedly: %v", err)
@@ -120,7 +121,7 @@ func TestResolveLatestVersion_TwoLatestVersionsDoNotHaveAReleaseYet(t *testing.T
 
 	gcs := &repositories.GCSRepo{}
 	repos := core.CreateRepositories(gcs, nil, nil, nil, nil, false)
-	version, _, err := repos.ResolveVersion(tmpDir, versions.BazelUpstream, "latest")
+	version, _, err := repos.ResolveVersion(tmpDir, versions.BazelUpstream, "latest", config.Null())
 
 	if err != nil {
 		t.Fatalf("Version resolution failed unexpectedly: %v", err)
@@ -142,7 +143,7 @@ func TestResolveLatestVersion_ShouldOnlyReturnStableReleases(t *testing.T) {
 
 	gcs := &repositories.GCSRepo{}
 	repos := core.CreateRepositories(gcs, nil, nil, nil, nil, false)
-	version, _, err := repos.ResolveVersion(tmpDir, versions.BazelUpstream, "latest-1")
+	version, _, err := repos.ResolveVersion(tmpDir, versions.BazelUpstream, "latest-1", config.Null())
 
 	if err != nil {
 		t.Fatalf("Version resolution failed unexpectedly: %v", err)
@@ -161,7 +162,7 @@ func TestResolveLatestVersion_ShouldFailIfNotEnoughReleases(t *testing.T) {
 
 	gcs := &repositories.GCSRepo{}
 	repos := core.CreateRepositories(gcs, nil, nil, nil, nil, false)
-	_, _, err := repos.ResolveVersion(tmpDir, versions.BazelUpstream, "latest-1")
+	_, _, err := repos.ResolveVersion(tmpDir, versions.BazelUpstream, "latest-1", config.Null())
 
 	if err == nil {
 		t.Fatal("Expected ResolveVersion() to fail.")
@@ -178,7 +179,7 @@ func TestResolveLatestVersion_GCSIsDown(t *testing.T) {
 
 	gcs := &repositories.GCSRepo{}
 	repos := core.CreateRepositories(gcs, nil, nil, nil, nil, false)
-	_, _, err := repos.ResolveVersion(tmpDir, versions.BazelUpstream, "latest")
+	_, _, err := repos.ResolveVersion(tmpDir, versions.BazelUpstream, "latest", config.Null())
 
 	if err == nil {
 		t.Fatal("Expected resolveLatestVersion() to fail.")
@@ -196,7 +197,7 @@ func TestResolveLatestVersion_GitHubIsDown(t *testing.T) {
 	gh := repositories.CreateGitHubRepo("test_token")
 	repos := core.CreateRepositories(nil, nil, gh, nil, nil, false)
 
-	_, _, err := repos.ResolveVersion(tmpDir, "some_fork", "latest")
+	_, _, err := repos.ResolveVersion(tmpDir, "some_fork", "latest", config.Null())
 
 	if err == nil {
 		t.Fatal("Expected resolveLatestVersion() to fail.")
@@ -212,7 +213,7 @@ func TestAcceptRollingReleaseName(t *testing.T) {
 	repos := core.CreateRepositories(nil, nil, nil, nil, gcs, false)
 
 	for _, version := range []string{"10.0.0-pre.20201103.4", "10.0.0-pre.20201103.4.2"} {
-		resolvedVersion, _, err := repos.ResolveVersion(tmpDir, "", version)
+		resolvedVersion, _, err := repos.ResolveVersion(tmpDir, "", version, config.Null())
 
 		if err != nil {
 			t.Fatalf("ResolveVersion(%q, \"\", %q): expected no error, but got %v", tmpDir, version, err)
@@ -233,7 +234,7 @@ func TestResolveLatestRollingRelease(t *testing.T) {
 	gcs := &repositories.GCSRepo{}
 	repos := core.CreateRepositories(nil, nil, nil, nil, gcs, false)
 
-	version, _, err := repos.ResolveVersion(tmpDir, "", rollingReleaseIdentifier)
+	version, _, err := repos.ResolveVersion(tmpDir, "", rollingReleaseIdentifier, config.Null())
 
 	if err != nil {
 		t.Fatalf("ResolveVersion(%q, \"\", %q): expected no error, but got %v", tmpDir, rollingReleaseIdentifier, err)
@@ -257,7 +258,7 @@ func TestAcceptFloatingReleaseVersions(t *testing.T) {
 
 	gcs := &repositories.GCSRepo{}
 	repos := core.CreateRepositories(gcs, nil, nil, nil, nil, false)
-	version, _, err := repos.ResolveVersion(tmpDir, versions.BazelUpstream, "4.x")
+	version, _, err := repos.ResolveVersion(tmpDir, versions.BazelUpstream, "4.x", config.Null())
 
 	if err != nil {
 		t.Fatalf("Version resolution failed unexpectedly: %v", err)
